# Generated by Plain 0.32.0 on 2025-03-10 15:40

from plain import models
from plain.models import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("plainpageviews", "0004_alter_pageview_uuid_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="pageview",
            name="session_key",
            field=models.CharField(max_length=255, required=False),
        ),
        migrations.AlterField(
            model_name="pageview",
            name="timestamp",
            field=models.DateTimeField(auto_now_add=True),
        ),
        migrations.AlterField(
            model_name="pageview",
            name="url",
            field=models.URLField(max_length=1024),
        ),
        migrations.AlterField(
            model_name="pageview",
            name="user_id",
            field=models.CharField(max_length=255, required=False),
        ),
        migrations.AddIndex(
            model_name="pageview",
            index=models.Index(
                fields=["timestamp"], name="plainpagevi_timesta_da4eb2_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="pageview",
            index=models.Index(
                fields=["user_id"], name="plainpagevi_user_id_b40ca5_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="pageview",
            index=models.Index(
                fields=["session_key"], name="plainpagevi_session_5545cf_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="pageview",
            index=models.Index(fields=["url"], name="plainpagevi_url_d3e821_idx"),
        ),
    ]



# Generated by Plain 0.31.0 on 2025-03-08 21:33

import uuid

from plain import models
from plain.models import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("plainpageviews", "0003_alter_pageview_uuid"),
    ]

    operations = [
        migrations.AlterField(
            model_name="pageview",
            name="uuid",
            field=models.UUIDField(default=uuid.uuid4),
        ),
        migrations.AddConstraint(
            model_name="pageview",
            constraint=models.UniqueConstraint(
                fields=("uuid",), name="plainpageviews_pageview_unique_uuid"
            ),
        ),
    ]



# Generated by Plain 0.47.0 on 2025-06-06 17:45

from plain import models
from plain.models import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "plainpageviews",
            "0005_alter_pageview_session_key_alter_pageview_timestamp_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="pageview",
            name="referrer",
            field=models.CharField(max_length=1024, required=False),
        ),
    ]



import uuid

from plain import models


@models.register_model
class Pageview(models.Model):
    uuid = models.UUIDField(default=uuid.uuid4)

    url = models.URLField(max_length=1024)
    timestamp = models.DateTimeField(auto_now_add=True)

    title = models.CharField(max_length=512, required=False)
    # Referrers may not always be valid URLs (e.g. `android-app://...`).
    # Use a plain CharField so we don't validate the scheme or format.
    referrer = models.CharField(max_length=1024, required=False)

    user_id = models.CharField(max_length=255, required=False)
    session_key = models.CharField(max_length=255, required=False)

    class Meta:
        ordering = ["-timestamp"]
        indexes = [
            models.Index(fields=["timestamp"]),
            models.Index(fields=["user_id"]),
            models.Index(fields=["session_key"]),
            models.Index(fields=["url"]),
        ]
        constraints = [
            models.UniqueConstraint(
                fields=["uuid"], name="plainpageviews_pageview_unique_uuid"
            ),
        ]

    def __str__(self):
        return self.url



# Generated by Plain 0.15.0 on 2025-01-06 20:20

import uuid

from plain import models
from plain.models import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "plainpageviews",
            "0002_alter_pageview_referrer_alter_pageview_title_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="pageview",
            name="uuid",
            field=models.UUIDField(default=uuid.uuid4),
        ),
    ]
